@@ -39,8 +39,6 @@ class PollAnswerForm(forms.ModelForm):
 
 class BasePollAnswerFormset(BaseInlineFormSet):
     def clean(self):
-        if any(self.errors):
-            raise forms.ValidationError(self.errors)
         forms_cnt = (len(self.initial_forms) + len([form for form in self.extra_forms if form.has_changed()]) -
                      len(self.deleted_forms))
         if forms_cnt > defaults.PYBB_POLL_MAX_ANSWERS:
@@ -65,9 +63,12 @@ class PostForm(forms.ModelForm):
     class Meta(object):
         model = Post
         fields = ('body',)
+        widgets = {
+            'body': util.get_markup_engine().get_widget_cls(),
+        }
 
     def __init__(self, *args, **kwargs):
-    #Move args to kwargs
+        # Move args to kwargs
         if args:
             kwargs.update(dict(zip(inspect.getargspec(super(PostForm, self).__init__)[0][1:], args)))
         self.user = kwargs.pop('user', None)
@@ -77,7 +78,7 @@ class PostForm(forms.ModelForm):
         self.may_create_poll = kwargs.pop('may_create_poll', True)
         if not (self.topic or self.forum or ('instance' in kwargs)):
             raise ValueError('You should provide topic, forum or instance')
-            #Handle topic subject, poll type and question if editing topic head
+            # Handle topic subject, poll type and question if editing topic head
         if kwargs.get('instance', None) and (kwargs['instance'].topic.head == kwargs['instance']):
             kwargs.setdefault('initial', {})['name'] = kwargs['instance'].topic.name
             kwargs.setdefault('initial', {})['poll_type'] = kwargs['instance'].topic.poll_type
@@ -104,7 +105,7 @@ class PostForm(forms.ModelForm):
             defaults.PYBB_BODY_VALIDATOR(user, body)
 
         for cleaner in defaults.PYBB_BODY_CLEANERS:
-            body = cleaner(user, body)
+            body = util.get_body_cleaner(cleaner)(user, body)
         return body
 
     def clean(self):
